jQuery(document).ready(function() {
  $ = jQuery;
  
  // Remove height/width attributes from img.borealis
  $('img.borealis').each(function() {
    $(this).removeAttr('height');
    $(this).removeAttr('width');
  });
  
  // Call borealisImageRespond to initialize the images!
  borealisImageRespond();
  
  // When the screen is resized, check again!
  $(window).resize(function() {
    borealisImageRespond();
  });
});

//////////////////////////////
// Borealis Image Setup Function
//
// Loop over each image, and change their width depending on input width
// By default, if no width is passed in, we use parent width as opposed to 
//  image width because image width does not work reliably in all circumstances. 
//  This also allows different images on the page to be scaled differently and 
//  is not dependent on screen size.
// We swap the next size images in at 95% of the current image's actual width to help 
//  ensure a smooth flow between images by allowing for a buffer between sizes.
//
// Can be called by other JS to initialize Borealis RI.
// Called by default at start of borealis_ri.js
//////////////////////////////
function borealisImageRespond() {
  $('img.borealis').each(function() {
    var width = '';
    
    // A special exception needs to be made for FlexSlider due to the
    //  way it handles width. Assumes default FlexSlider layout with 
    //  flexslider class
    if ($(this).parents('.flexslider')) {
      width = $(this).parents('.flexslider').width();
    }
    else {
      width = $(this).parent().width();
    }
    
    // console.log(biWidth);
    if (width >= 238 && width < 475) {
      borealisImgReplace($(this), 'respondmedium', 'respondlarge');
    }
    else if (width >= 475 && width < 950) {
      borealisImgReplace($(this), 'respondlarge', 'respondxl');
    }
    else if (width >= 950) {
      borealisImgReplace($(this), 'respondxl', 'respondxl2');
    }
    else {
      borealisImgReplace($(this), 'respondsmall', 'respondmedium');
    }
  });
}

//////////////////////////////
// Image Replacement Function
//////////////////////////////
function borealisImgReplace(obj, regularSize, doubleSize) {
  // Determine the device pixel ratio of the device
  // console.log(regularSize);
  var dpr = '';
  if (window.devicePixelRatio == undefined) {
    // If devicePixelRatio is not defined, set it to 1
    dpr = 1;
  }
  else {
    // If it is defined, set it as is.
    // For intance, current Google Chrome returns 1, iPhone 4+ returns 2
    dpr = window.devicePixelRatio;
  }
  
  var src = obj.attr('src');
  // Only do SRC replacement if the image's SRC has Borealis in it.
  if (src.indexOf('borealis_') != -1) {
    // Split the SRC up, we're going to be taking parts.
    src = src.split('/');
    var newSrc = '';
    var doubleSrc = '';
    // Loop over each part of the SRC, looking for the Borealis part
    $.each(src, function(index, value){
      if (value.indexOf('borealis_') != -1) {
        // Replacement Value
        var replace_name = '';
        var style_name = '';
        // console.log(value);
        
        
        // if (regularSize == 'respondmedium' && dpr < 2) {
        //           if (value.indexOf('_respondmedium') == -1 || value.indexOf('_respondlarge') == -1 || !value.indexOf('_respondxl')) {
        //             style_name = value.replace('_respondsmall', '');
        //             replace_name = style_name + '_' + regularSize;
        //             // console.log(replace_name);
        //           }
        //         }
        //         else if (regularSize == 'respondlarge' && dpr < 2) {
        //           
        //           if (value.indexOf('_respondlarge') == -1 || value.indexOf('_respondxl') == -1) {
        //             // console.log('Banana');
        //             style_name = value.replace('_respondsmall', '');
        //             style_name = style_name.replace('_respondmedium', '');
        //             replace_name = style_name + '_' + regularSize;
        //             // console.log(replace_name);
        //             // console.log('respondlarge');
        //             
        //           }
        //         }
        //         else if (regularSize == 'respondxl' && dpr < 2) {
        //           if (value.indexOf('_respondxl') == -1) {
        //             style_name = value.replace('_respondsmall', '');
        //             style_name = style_name.replace('_respondmedium', '');
        //             style_name = style_name.replace('_respondlarge', '');
        //             replace_name = style_name + '_' + regularSize;
        //             // console.log(replace_name);
        //             // console.log('respondxl');
        //           }
        //         }
        //         else if (regularSize == 'respondsmall' && dpr < 2) {
        //           replace_name = value;
        //         }
        
        
        // Strip all possible Borealis extensions
        style_name = value.replace('_respondsmall', '');
        style_name = style_name.replace('_respondmedium', '');
        style_name = style_name.replace('_respondlarge', '');
        style_name = style_name.replace('_respondxl', '');
        style_name = style_name.replace('_respondxl2', '');
        
        if (dpr < 2) {
          replace_name = style_name + '_' + regularSize;
        }
        else {
          replace_name = style_name + '_' + doubleSize;
        }
        
        // Append Replacement Name onto New SRC.
        // console.log(replace_name);
        newSrc += '/' + replace_name;
        }
        else {
        // Append whatever the current SRC item is onto New SRC.
        newSrc += '/' + value;
      }
    });
    // New SRC starts with a /, get rid of that.
    newSrc = newSrc.substr(1);
    // Add New SRC to Image, this swapping the image.
    obj.attr('src', newSrc);
  }
}
